@@ -36,6 +36,7 @@ import (
 var _ = Describe("Instance Type SpecFinder", func() {
 	const (
 		nonExistingResourceName = "non-existing-resource"
+		storedName              = "stored"
 	)
 
 	type instancetypeSpecFinder interface {
@@ -295,6 +296,36 @@ var _ = Describe("Instance Type SpecFinder", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(foundInstancetypeSpec).To(HaveValue(Equal(clusterInstancetype.Spec)))
 		})
+
+		It("find returns only referenced object - bug #14595", func() {
+			// Make a slightly altered copy of the object already present in the client and store it in a CR
+			stored := clusterInstancetype.DeepCopy()
+			stored.ObjectMeta.Name = storedName
+			stored.Spec.CPU.Guest = uint32(99)
+
+			controllerRevision, err := revision.CreateControllerRevision(vm, stored)
+			Expect(err).ToNot(HaveOccurred())
+
+			_, err = virtClient.AppsV1().ControllerRevisions(vm.Namespace).Create(
+				context.Background(), controllerRevision, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			// Assert that the spec points to the original clusterInstancetype
+			Expect(vm.Spec.Instancetype.Name).To(Equal(clusterInstancetype.Name))
+
+			// Reference this stored version from the VM status
+			vm.Status.InstancetypeRef = &v1.InstancetypeStatusRef{
+				Name: stored.Name,
+				Kind: stored.Kind,
+				ControllerRevisionRef: &v1.ControllerRevisionRef{
+					Name: controllerRevision.Name,
+				},
+			}
+
+			foundInstancetypeSpec, err := finder.Find(vm)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(foundInstancetypeSpec).To(HaveValue(Equal(clusterInstancetype.Spec)))
+		})
 	})
 
 	Context("Using namespaced Instancetype", func() {
@@ -479,5 +510,35 @@ var _ = Describe("Instance Type SpecFinder", func() {
 			Expect(err).ToNot(HaveOccurred())
 			Expect(foundInstancetypeSpec).To(HaveValue(Equal(fakeInstancetype.Spec)))
 		})
+
+		It("find returns only referenced object - bug #14595", func() {
+			// Make a slightly altered copy of the object already present in the client and store it in a CR
+			stored := fakeInstancetype.DeepCopy()
+			stored.ObjectMeta.Name = storedName
+			stored.Spec.CPU.Guest = uint32(99)
+
+			controllerRevision, err := revision.CreateControllerRevision(vm, stored)
+			Expect(err).ToNot(HaveOccurred())
+
+			_, err = virtClient.AppsV1().ControllerRevisions(vm.Namespace).Create(
+				context.Background(), controllerRevision, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			// Assert that the spec points to the original clusterInstancetype
+			Expect(vm.Spec.Instancetype.Name).To(Equal(fakeInstancetype.Name))
+
+			// Reference this stored version from the VM status
+			vm.Status.InstancetypeRef = &v1.InstancetypeStatusRef{
+				Name: stored.Name,
+				Kind: stored.Kind,
+				ControllerRevisionRef: &v1.ControllerRevisionRef{
+					Name: controllerRevision.Name,
+				},
+			}
+
+			foundInstancetypeSpec, err := finder.Find(vm)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(foundInstancetypeSpec).To(HaveValue(Equal(fakeInstancetype.Spec)))
+		})
 	})
 })
