@@ -830,20 +830,28 @@ func (t *vmRestoreTarget) generateRestoredVMSpec(snapshotVM *snapshotv1.VirtualM
 			Spec:   *snapshotVM.Spec.DeepCopy(),
 			Status: kubevirtv1.VirtualMachineStatus{},
 		}
-
+		if newVM.Spec.Running != nil {
+			newVM.Spec.Running = pointer.P(false)
+		} else {
+			newVM.Spec.RunStrategy = pointer.P(kubevirtv1.RunStrategyHalted)
+		}
 	} else {
 		newVM = t.vm.DeepCopy()
 		newVM.Spec = *snapshotVM.Spec.DeepCopy()
+		if t.vm.Spec.Running != nil {
+			newVM.Spec.Running = pointer.P(false)
+			newVM.Spec.RunStrategy = nil
+		} else {
+			runStrategy, err := t.vm.RunStrategy()
+			if err != nil {
+				return nil, err
+			}
+			// make sure an existing VM keeps the same run strategy as before the restore
+			newVM.Spec.RunStrategy = pointer.P(runStrategy)
+			newVM.Spec.Running = nil
+		}
 	}
 
-	// update Running state in case snapshot was on online VM
-	if newVM.Spec.RunStrategy != nil {
-		runStrategyHalted := kubevirtv1.RunStrategyHalted
-		newVM.Spec.RunStrategy = &runStrategyHalted
-	} else if newVM.Spec.Running != nil {
-		running := false
-		newVM.Spec.Running = &running
-	}
 	newVM.Spec.DataVolumeTemplates = newTemplates
 	newVM.Spec.Template.Spec.Volumes = newVolumes
 	setLastRestoreAnnotation(t.vmRestore, newVM)
