@@ -21,6 +21,7 @@ package types
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"maps"
 
@@ -332,3 +333,25 @@ func (d *DataVolumeConditionManager) HasConditionWithStatusAndReason(dv *cdiv1.D
 	c := d.GetCondition(dv, cond)
 	return c != nil && c.Status == status && c.Reason == reason
 }
+
+var ErrDVNotFound = errors.New("Datavolume not found")
+
+type DVNotFoundError struct {
+	DVName string
+	Err    error
+}
+
+func NewDVNotFoundError(name string) error {
+	return &DVNotFoundError{DVName: name, Err: ErrDVNotFound}
+}
+
+func (e *DVNotFoundError) Error() string {
+	if e.DVName == "" {
+		return "datavolume not defined"
+	}
+	return fmt.Sprintf("the datavolume %s doesn't exist", e.DVName)
+}
+
+func (e *DVNotFoundError) Unwrap() error {
+	return e.Err
+}
