@@ -17,6 +17,8 @@ func (app *SubresourceAPIApp) ConsoleRequestHandler(request *restful.Request, re
 	activeConnectionMetric := apimetrics.NewActiveConsoleConnection(request.PathParameter("namespace"), request.PathParameter("name"))
 	defer activeConnectionMetric.Dec()
 
+	defer apimetrics.SetVMILastConnectionTimestamp(request.PathParameter("namespace"), request.PathParameter("name"))
+
 	streamer := NewRawStreamer(
 		app.FetchVirtualMachineInstance,
 		validateVMIForConsole,
@@ -29,7 +31,7 @@ func (app *SubresourceAPIApp) ConsoleRequestHandler(request *restful.Request, re
 }
 
 func validateVMIForConsole(vmi *v1.VirtualMachineInstance) *errors.StatusError {
-	if vmi.Spec.Domain.Devices.AutoattachSerialConsole != nil && *vmi.Spec.Domain.Devices.AutoattachSerialConsole == false {
+	if vmi.Spec.Domain.Devices.AutoattachSerialConsole != nil && !*vmi.Spec.Domain.Devices.AutoattachSerialConsole {
 		err := fmt.Errorf("No serial consoles are present.")
 		log.Log.Object(vmi).Reason(err).Error("Can't establish a serial console connection.")
 		return errors.NewBadRequest(err.Error())
