@@ -32,7 +32,6 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 
 	webhookutils "kubevirt.io/kubevirt/pkg/util/webhooks"
-	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
 )
@@ -101,9 +100,10 @@ func (admitter *VMIUpdateAdmitter) Admit(_ context.Context, ar *admissionv1.Admi
 	}
 
 	// Reject VMI update if VMI spec changed
+	_, isKubeVirtServiceAccount := admitter.kubeVirtServiceAccounts[ar.Request.UserInfo.Username]
 	if !equality.Semantic.DeepEqual(newVMI.Spec, oldVMI.Spec) {
 		// Only allow the KubeVirt SA to modify the VMI spec, since that means it went through the sub resource.
-		if _, isKubeVirtServiceAccount := admitter.kubeVirtServiceAccounts[ar.Request.UserInfo.Username]; isKubeVirtServiceAccount {
+		if isKubeVirtServiceAccount {
 			hotplugResponse := admitHotplug(oldVMI, newVMI, admitter.clusterConfig)
 			if hotplugResponse != nil {
 				return hotplugResponse
@@ -118,8 +118,10 @@ func (admitter *VMIUpdateAdmitter) Admit(_ context.Context, ar *admissionv1.Admi
 		}
 	}
 
-	if reviewResponse := admitVMILabelsUpdate(newVMI, oldVMI, ar); reviewResponse != nil {
-		return reviewResponse
+	if !isKubeVirtServiceAccount {
+		if reviewResponse := admitVMILabelsUpdate(newVMI, oldVMI); reviewResponse != nil {
+			return reviewResponse
+		}
 	}
 
 	return &admissionv1.AdmissionResponse{
@@ -368,12 +370,7 @@ func getMigratedVolumeMaps(migratedDisks []v1.StorageMigratedVolumeInfo) map[str
 func admitVMILabelsUpdate(
 	newVMI *v1.VirtualMachineInstance,
 	oldVMI *v1.VirtualMachineInstance,
-	ar *admissionv1.AdmissionReview) *admissionv1.AdmissionResponse {
-
-	if webhooks.IsKubeVirtServiceAccount(ar.Request.UserInfo.Username) {
-		return nil
-	}
-
+) *admissionv1.AdmissionResponse {
 	oldLabels := filterKubevirtLabels(oldVMI.ObjectMeta.Labels)
 	newLabels := filterKubevirtLabels(newVMI.ObjectMeta.Labels)
 
