@@ -48,6 +48,7 @@ var _ = Describe("Node-labeller ", func() {
 	var nlController *NodeLabeller
 	var kubeClient *fake.Clientset
 	var cpuCounter *libvirtxml.CapsHostCPUCounter
+	var guestsCaps []libvirtxml.CapsGuest
 
 	initNodeLabeller := func(kubevirt *v1.KubeVirt) {
 		config, _, _ := testutils.NewFakeClusterConfigUsingKV(kubevirt)
@@ -55,7 +56,7 @@ var _ = Describe("Node-labeller ", func() {
 		recorder.IncludeObject = true
 
 		var err error
-		nlController, err = newNodeLabeller(config, kubeClient.CoreV1().Nodes(), nodeName, "testdata", recorder, cpuCounter)
+		nlController, err = newNodeLabeller(config, kubeClient.CoreV1().Nodes(), nodeName, "testdata", recorder, cpuCounter, guestsCaps)
 		Expect(err).ToNot(HaveOccurred())
 	}
 
@@ -66,6 +67,17 @@ var _ = Describe("Node-labeller ", func() {
 			Scaling:   "no",
 		}
 
+		guestsCaps = []libvirtxml.CapsGuest{
+			{
+				OSType: "test",
+				Arch: libvirtxml.CapsGuestArch{
+					Machines: []libvirtxml.CapsGuestMachine{
+						{Name: "testmachine"},
+					},
+				},
+			},
+		}
+
 		node := newNode(nodeName)
 		kubeClient = fake.NewSimpleClientset(node)
 		initNodeLabeller(&v1.KubeVirt{
@@ -122,6 +134,14 @@ var _ = Describe("Node-labeller ", func() {
 		node := retrieveNode(kubeClient)
 		Expect(node.Labels).To(HaveKey(HavePrefix(v1.HostModelCPULabel)))
 	})
+
+	It("should add supported machine type labels", func() {
+		res := nlController.execute()
+		Expect(res).To(BeTrue())
+
+		node := retrieveNode(kubeClient)
+		Expect(node.Labels).To(HaveKey(v1.SupportedMachineTypeLabel + "testmachine"))
+	})
 	It("should add host cpu required features", func() {
 		res := nlController.execute()
 		Expect(res).To(BeTrue())
@@ -270,6 +290,33 @@ var _ = Describe("Node-labeller ", func() {
 		// Added in BeforeEach
 		Expect(node.Labels).To(HaveKey("INeedToBeHere"))
 	})
+
+	DescribeTable("should add machine type labels", func(machines []libvirtxml.CapsGuestMachine, arch string) {
+		guestsCaps[0].Arch.Machines = machines
+
+		initNodeLabeller(&v1.KubeVirt{})
+		nlController.arch = newArchLabeller(arch)
+		mockQueue := testutils.NewMockWorkQueue(nlController.queue)
+		nlController.queue = mockQueue
+
+		mockQueue.ExpectAdds(1)
+		nlController.queue.Add(nodeName)
+		mockQueue.Wait()
+
+		res := nlController.execute()
+		Expect(res).To(BeTrue(), "labeller should complete successfully")
+
+		node := retrieveNode(kubeClient)
+
+		for _, machine := range machines {
+			expectedLabelKey := v1.SupportedMachineTypeLabel + machine.Name
+			Expect(node.Labels).To(HaveKey(expectedLabelKey), "expected machine type label %s to be present", expectedLabelKey)
+		}
+	},
+		Entry("for amd64", []libvirtxml.CapsGuestMachine{{Name: "q35"}, {Name: "q35-rhel9.6.0"}}, amd64),
+		Entry("for arm64", []libvirtxml.CapsGuestMachine{{Name: "virt"}, {Name: "virt-rhel9.6.0"}}, arm64),
+	)
+
 })
 
 func newNode(name string) *k8sv1.Node {
