@@ -31,11 +31,9 @@ var _ = Describe("Apply PDBs", func() {
 	var expectations *util.Expectations
 	var kv *v1.KubeVirt
 	var deployment *v12.Deployment
-	var mockPodDisruptionBudgetCacheStore *MockStore
 	var requiredPDB *policyv1.PodDisruptionBudget
 	var r *Reconciler
 	var mockGeneration int64
-	var err error
 
 	getCachedPDB := func() *policyv1.PodDisruptionBudget {
 		Expect(requiredPDB).ToNot(BeNil())
@@ -76,7 +74,7 @@ var _ = Describe("Apply PDBs", func() {
 			Registry:        Registry,
 			KubeVirtVersion: Version,
 		}
-		deployment, err = components.NewApiServerDeployment(
+		deployment = components.NewApiServerDeployment(
 			Namespace,
 			virtApiConfig.GetImageRegistry(),
 			virtApiConfig.GetImagePrefix(),
@@ -89,15 +87,11 @@ var _ = Describe("Apply PDBs", func() {
 			virtApiConfig.GetImagePullSecrets(),
 			virtApiConfig.GetVerbosity(),
 			virtApiConfig.GetExtraEnv())
-		Expect(err).ToNot(HaveOccurred())
 
 		kv.Status.TargetKubeVirtRegistry = Registry
 		kv.Status.TargetKubeVirtVersion = Version
 		kv.Status.TargetDeploymentID = Id
 
-		mockPodDisruptionBudgetCacheStore = &MockStore{}
-		err = stores.PodDisruptionBudgetCache.Add(mockPodDisruptionBudgetCacheStore)
-
 		mockGeneration = 123
 
 		// Set required PDB
