@@ -20,18 +20,19 @@
 package clone
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
 	"github.com/spf13/cobra"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/rand"
-	"k8s.io/client-go/tools/clientcmd"
-	clonev1alpha1 "kubevirt.io/api/clone/v1alpha1"
+	clone "kubevirt.io/api/clone/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	"sigs.k8s.io/yaml"
 
 	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virtctl/clientconfig"
 )
 
 const (
@@ -66,29 +67,22 @@ type createClone struct {
 	templateAnnotationFilters []string
 	newMacAddresses           []string
 	newSmbiosSerial           string
-
-	clientConfig clientcmd.ClientConfig
 }
 
-type cloneSpec clonev1alpha1.VirtualMachineCloneSpec
+type cloneSpec clone.VirtualMachineCloneSpec
 type optionFn func(*createClone, *cloneSpec) error
 
 var optFns = map[string]optionFn{
 	NewMacAddressesFlag: withNewMacAddresses,
 }
 
-func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
-	c := createClone{
-		clientConfig: clientConfig,
-	}
-
+func NewCommand() *cobra.Command {
+	c := createClone{}
 	cmd := &cobra.Command{
 		Use:     Clone,
 		Short:   "Create a clone object manifest",
 		Example: c.usage(),
-		RunE: func(cmd *cobra.Command, _ []string) error {
-			return c.run(cmd)
-		},
+		RunE:    c.run,
 	}
 
 	const emptyValue = ""
@@ -179,10 +173,10 @@ func (c *createClone) usage() string {
   {{ProgramName}} create clone --source-name sourceVM | kubectl create -f -`
 }
 
-func (c *createClone) newClone() (*clonev1alpha1.VirtualMachineClone, error) {
-	clone := kubecli.NewMinimalClone(c.name)
+func (c *createClone) newClone() (*clone.VirtualMachineClone, error) {
+	vmClone := kubecli.NewMinimalClone(c.name)
 	if c.namespace != "" {
-		clone.Namespace = c.namespace
+		vmClone.Namespace = c.namespace
 	}
 
 	source, err := c.typeToTypedLocalObjectReference(c.sourceType, c.sourceName, true)
@@ -195,25 +189,25 @@ func (c *createClone) newClone() (*clonev1alpha1.VirtualMachineClone, error) {
 		return nil, err
 	}
 
-	clone.Spec = clonev1alpha1.VirtualMachineCloneSpec{
+	vmClone.Spec = clone.VirtualMachineCloneSpec{
 		Source:            source,
 		Target:            target,
 		AnnotationFilters: c.annotationFilters,
 		LabelFilters:      c.labelFilters,
-		Template: clonev1alpha1.VirtualMachineCloneTemplateFilters{
+		Template: clone.VirtualMachineCloneTemplateFilters{
 			AnnotationFilters: c.templateAnnotationFilters,
 			LabelFilters:      c.templateLabelFilters,
 		},
 	}
 
 	if c.newSmbiosSerial != "" {
-		clone.Spec.NewSMBiosSerial = pointer.P(c.newSmbiosSerial)
+		vmClone.Spec.NewSMBiosSerial = pointer.P(c.newSmbiosSerial)
 	}
 
-	return clone, nil
+	return vmClone, nil
 }
 
-func (c *createClone) applyFlags(cmd *cobra.Command, spec *clonev1alpha1.VirtualMachineCloneSpec) error {
+func (c *createClone) applyFlags(cmd *cobra.Command, spec *clone.VirtualMachineCloneSpec) error {
 	for flag := range optFns {
 		if cmd.Flags().Changed(flag) {
 			if err := optFns[flag](c, (*cloneSpec)(spec)); err != nil {
@@ -225,8 +219,8 @@ func (c *createClone) applyFlags(cmd *cobra.Command, spec *clonev1alpha1.Virtual
 	return nil
 }
 
-func (c *createClone) run(cmd *cobra.Command) error {
-	if err := c.setDefaults(); err != nil {
+func (c *createClone) run(cmd *cobra.Command, _ []string) error {
+	if err := c.setDefaults(cmd.Context()); err != nil {
 		return err
 	}
 
@@ -298,8 +292,8 @@ func (c *createClone) typeToTypedLocalObjectReference(sourceOrTargetType, source
 	}, nil
 }
 
-func (c *createClone) setDefaults() error {
-	namespace, overridden, err := c.clientConfig.Namespace()
+func (c *createClone) setDefaults(ctx context.Context) error {
+	_, namespace, overridden, err := clientconfig.ClientAndNamespaceFromContext(ctx)
 	if err != nil {
 		return err
 	}
