@@ -13,21 +13,15 @@ import (
 	"golang.org/x/crypto/ssh/agent"
 	"golang.org/x/term"
 
-	"k8s.io/client-go/tools/clientcmd"
-	kvcorev1 "kubevirt.io/client-go/kubevirt/typed/core/v1"
-
 	"kubevirt.io/client-go/kubecli"
+	kvcorev1 "kubevirt.io/client-go/kubevirt/typed/core/v1"
 	"kubevirt.io/client-go/log"
 )
 
-const (
-	wrapLocalSSHDefault = false
-)
-
 func additionalUsage() string {
 	return fmt.Sprintf(`
 	# Connect to 'testvmi' using the local ssh binary found in $PATH:
-	{{ProgramName}} ssh --%s=true jdoe@testvmi`,
+	{{ProgramName}} ssh --%s=true jdoe@vmi/testvmi`,
 		wrapLocalSSHFlag,
 	)
 }
@@ -40,20 +34,20 @@ func addAdditionalCommandlineArgs(flagset *pflag.FlagSet, opts *SSHOptions) {
 }
 
 type NativeSSHConnection struct {
-	ClientConfig clientcmd.ClientConfig
-	Options      SSHOptions
+	Client  kubecli.KubevirtClient
+	Options SSHOptions
 }
 
-func (o *SSH) nativeSSH(kind, namespace, name string) error {
+func (o *SSH) nativeSSH(kind, namespace, name string, client kubecli.KubevirtClient) error {
 	conn := NativeSSHConnection{
-		ClientConfig: o.clientConfig,
-		Options:      o.options,
+		Client:  client,
+		Options: o.options,
 	}
-	client, err := conn.PrepareSSHClient(kind, namespace, name)
+	sshClient, err := conn.PrepareSSHClient(kind, namespace, name)
 	if err != nil {
 		return err
 	}
-	return conn.StartSession(client, o.command)
+	return conn.StartSession(sshClient, o.command)
 }
 
 func (o *NativeSSHConnection) PrepareSSHClient(kind, namespace, name string) (*ssh.Client, error) {
@@ -205,19 +199,17 @@ func (o *NativeSSHConnection) StartSession(client *ssh.Client, command string) e
 }
 
 func (o *NativeSSHConnection) prepareSSHTunnel(kind, namespace, name string) (kvcorev1.StreamInterface, error) {
-	virtCli, err := kubecli.GetKubevirtClientFromClientConfig(o.ClientConfig)
-	if err != nil {
-		return nil, err
-	}
-
-	var stream kvcorev1.StreamInterface
+	var (
+		stream kvcorev1.StreamInterface
+		err    error
+	)
 	if kind == "vmi" {
-		stream, err = virtCli.VirtualMachineInstance(namespace).PortForward(name, o.Options.SSHPort, "tcp")
+		stream, err = o.Client.VirtualMachineInstance(namespace).PortForward(name, o.Options.SSHPort, "tcp")
 		if err != nil {
 			return nil, fmt.Errorf("can't access VMI %s: %w", name, err)
 		}
 	} else if kind == "vm" {
-		stream, err = virtCli.VirtualMachine(namespace).PortForward(name, o.Options.SSHPort, "tcp")
+		stream, err = o.Client.VirtualMachine(namespace).PortForward(name, o.Options.SSHPort, "tcp")
 		if err != nil {
 			return nil, fmt.Errorf("can't access VM %s: %w", name, err)
 		}
